@@ -1,7 +1,9 @@
 from werkzeug import wrappers
 import os
+from io import BytesIO
 from PIL import Image
 from requests.models import Response
+import json
 
 def get_upload_image_mock_request(image_path):
     with open(image_path, "rb") as img:
